@@ -249,13 +249,15 @@ handle_gdb_input (GIOChannel *ioc, GIOCondition condition, gpointer data)
 		GtkTextBuffer *buffy;
 		GtkTextView *tv;
 		char *utftext;
+		gsize localelen;
 		gsize utflen;
 
 		tv = GTK_TEXT_VIEW (GET_WIDGET ("gdb-text"));
 		buffy = gtk_text_view_get_buffer (tv);
 
 		gtk_text_buffer_get_end_iter (buffy, &end);
-		utftext = g_locale_to_utf8 (buf, len, NULL, &utflen, NULL);
+		/* gdb charset is ISO-8859-1 */
+		utftext = g_convert_with_fallback (buf, len, "UTF-8", "ISO-8859-1", NULL, &localelen, &utflen, NULL);
 		gtk_text_buffer_insert (buffy, &end, utftext, utflen);
 		g_free (utftext);
 	}
